@@ -20,7 +20,6 @@ from .taggerlib.utils import create_issue_query_dict
 SETTINGS = MetronTaggerSettings()
 
 
-# TODO: Consider making this a dict or tuple
 class MultipleMatch:
     """Class to hold information on searches with multiple matches"""
 
@@ -29,7 +28,6 @@ class MultipleMatch:
         self.matches = match_list
 
 
-# TODO: Consider making this a dict or tuple
 class OnlineMatchResults:
     """Class to track online match results"""
 
@@ -74,6 +72,11 @@ def write_issue_metadata(filename: Path, issue_id: int, talker: MetronTalker) ->
         print(f"there was a problem writing metadate for '{filename.name}'")
 
 
+def print_choices_to_user(match_set) -> None:
+    for (counter, match) in enumerate(match_set, start=1):
+        print(f"{counter}. {match['__str__']} ({match['cover_date']})")
+
+
 def select_choice_from_multiple_matches(filename: Path, match_set) -> Optional[int]:
     """
     Function to ask user to choice which issue metadata to write,
@@ -83,9 +86,7 @@ def select_choice_from_multiple_matches(filename: Path, match_set) -> Optional[i
 
     # sort match list by cover date
     match_set = sorted(match_set, key=lambda m: m["cover_date"])
-
-    for (counter, match) in enumerate(match_set, start=1):
-        print(f"{counter}. {match['__str__']} ({match['cover_date']})")
+    print_choices_to_user(match_set)
 
     while True:
         i = input("Choose a match #, or 's' to skip: ")
@@ -94,11 +95,9 @@ def select_choice_from_multiple_matches(filename: Path, match_set) -> Optional[i
 
     if i != "s":
         i = int(i) - 1
-        issue_id = match_set[i]["id"]
+        return match_set[i]["id"]
     else:
-        issue_id = None
-
-    return issue_id
+        return None
 
 
 def workable_comic(comic: ComicArchive) -> bool:
@@ -248,7 +247,6 @@ def identify_comics(file_list: List[Path], ignore: bool) -> None:
         else:
             if not multiple_match:
                 print(f"no match for '{filename.name}'")
-                continue
 
     # Print match results & handle files with multiple matches
     post_process_matches(match_results, talker)
